@@ -49,8 +49,9 @@ itcl::class FitsFile {
 
      public method _transformFileName { name }
      public method _reverseTransformedFileName { name }
+     public method _isEmptyDir { dir }
      public method getHeader2String {}
-     public method translateKeyWords { colName rowNum }
+     public method translateKeyWords { colName rowNum dest tempFile }
      public method getDummyHeader2String {{dest {}} RAColNum_ DecColNum_}
      public method getHeaderKeyWord { str img }
      public method assembleWcsHeader { img {selection "DEFAULT"} } 
@@ -350,11 +351,19 @@ itcl::body FitsFile::_transformFileName { name } {
      return $newName
 }
 
+itcl::body FitsFile::_isEmptyDir { dir } {
+     set filenames [glob -nocomplain -tails -directory $dir * .*]
+     return [expr {![llength [lsearch -all -not -regexp $filenames {^\.\.?$}]]}]
+}
+
 itcl::body FitsFile::_reverseTransformedFileName { name } {
      if { $_oldName != $name && [file exists $name] } {
         file rename $name $_oldName
      }
 
+     if { [_isEmptyDir [file dirname $name]] == 1 } {
+        file delete [file dirname $name]
+     }
      return
 }
 
@@ -1409,9 +1418,9 @@ itcl::body FitsFile::moveToHDU {numHDU_} {
     if { [catch {$fitsfile move $numHDU_} ] == 1 } {
 	error "Cannot access HDU extension [expr $numHDU_ -1]. Does the file still exist?"
 	return
-    } else {
+     } else {
 	set currentHDU $numHDU_
-    }
+     }
     
 }
 
@@ -2498,10 +2507,10 @@ itcl::body FitsFile::freeChild { extNum_ } {
    }
 }
 
-itcl::body FitsFile::translateKeyWords { colName rowNum } {
+itcl::body FitsFile::translateKeyWords { colName rowNum dest tempFile } {
    # wrapper to call fits_copy_cell2image in cfitsio
    # return new header string and wcs info
-   return [$fitsfile get translatedKeywords $colName $rowNum]
+   return [$fitsfile get translatedKeywords $colName $rowNum $dest $tempFile]
 }
 
 itcl::body FitsFile::getHeader2String {} {
