@@ -789,7 +789,7 @@ itcl::body FitsHeader::_saveFile {} {
 
 itcl::body FitsHeader::_updateHL {} {
     if { [lsearch $_keyList "EXTNAME "]<0 } {
-       $_fatherFitsExtension updateHL EXTNAME NoName
+       # $_fatherFitsExtension updateHL EXTNAME NoName
     } else {
        set extVal [lindex [lindex [$_fFile getKeyword EXTNAME] 0] 1]
        $_fatherFitsExtension updateHL EXTNAME [string trim $extVal {' }]
