@@ -345,16 +345,21 @@ proc exitCmd { {force_ 0} } {
        if { [$i closeCmd $force_] } return
     }
     set g_isExitting 1 
-    after idle {itcl::delete object fv}
 
     # Pan Chai: clean up the backup directory
     if { [info exists fvTmp] && [string first $fvTmp $g_backupDir] > 0 } {
        set fileNameList [eval glob -directory {$g_backupDir} -nocomplain "*"]
        foreach name $fileNameList {
-          catch { file delete -force $name } err
+          if [file exist $name] {
+             catch { file delete -force $name } err
+          }
+       }
+       if [file exist $g_backupDir] {
+          catch { file delete -force $g_backupDir } err
        }
-       catch { file delete -force $g_backupDir } err
     }
+    # after idle {itcl::delete object fv}
+    exit
 }
 
 
