@@ -3,12 +3,12 @@ itcl::class fvApp {
    destructor {}
 
    public  method processOptions { opts }
+   public method _setupFont { }
 
    private method _loadLibs { }
    private method _setupColormap { }
    private method _setupOptions { }
    private method _setupBindings { }
-   private method _setupFont { }
    private method _setupBackup { }
    private method _correctPath { path }
 
@@ -40,13 +40,13 @@ itcl::body fvApp::constructor {args} {
       wm withdraw .
    }
  
-   set g_fvVersion 5.3
+   set g_fvVersion 5.4
    _setupOptions
-   _setupFont
 
    # Initialize preferences before searching through command-line options
 
    set fvPrefObj [fvPreferences ::fvPref]
+   _setupFont
 
    _loadLibs
    set unusedArgs [processOptions $args]
@@ -296,6 +296,7 @@ itcl::body fvApp::_setupOptions { } {
     global g_titleFont
     global g_entryFont
 
+   global env
    global g_hasSAOtng g_hasDS9
    global g_listObjs
    global g_histoFileID
@@ -407,18 +408,24 @@ itcl::body fvApp::_setupFont { } {
     global g_charPix
     global isWin isMac
 
+    catch { font delete g_titleFont g_notebookTitleFont g_entryFont }
+    catch { destroy .dummyFnt1 }
+    catch { destroy .dummyFnt2 }
+    catch { destroy .dummyFnt3 }
+    catch { destroy .dummyFnt4 }
+
     if { $isWin } {
-       font create g_titleFont -family Arial             -size -12
-       font create g_notebookTitleFont -family Arial     -size -14
+       font create g_titleFont -family Arial             -size -$fvPref::FontSize
+       font create g_notebookTitleFont -family Arial     -size -[expr $fvPref::FontSize + 2]
     } elseif { $isMac } {
-       font create g_titleFont -family system    -size -12
-       font create g_notebookTitleFont -family system -size -14
+       font create g_titleFont -family system    -size -$fvPref::FontSize
+       font create g_notebookTitleFont -family system -size -[expr $fvPref::FontSize + 2]
     } else {
-       font create g_titleFont -family Helvetica -size -12 -weight bold
-       font create g_notebookTitleFont -family Helvetica -size -14 -weight bold
+       font create g_titleFont -family Helvetica -size -$fvPref::FontSize -weight bold
+       font create g_notebookTitleFont -family Helvetica -size -[expr $fvPref::FontSize + 2] -weight bold
     }
 
-    font create g_entryFont -family Courier -size -12
+    font create g_entryFont -family Courier -size -$fvPref::FontSize
     set g_charPix      [font measure g_entryFont m]
 
     # These lines guarantee that the default fonts are always loaded.
