@@ -35,6 +35,10 @@ itcl::class fvPreferences {
       method _changeWindowColors { win type }
       method _toggleChoice {}
 
+      method _toggleCheckedSizeState { dim }
+      method _deleteCheckedSize { {op "delete"} }
+      method _addNewSize {}
+
       variable note
       variable _FVRC
       variable _padXAmnt 10
@@ -45,6 +49,9 @@ itcl::class fvPreferences {
       variable _previousDirectory ""
       variable viewerWindow ""
       variable previousImgDisplayer ""
+
+      variable sizeCheckList {}
+      variable _graphDefaultWndw ""
    }
 }
 
@@ -91,8 +98,10 @@ itcl::body fvPreferences::constructor { args } {
       variable ds9LibPath           
       variable winManagement        Keep
       variable graphDispSize        [list 300 300]
+      variable FontSize             12
       variable webModulesURLsHead   "http://heasarc.gsfc.nasa.gov/hera/"
       variable BrowserSetting       "None Defined"
+      variable GraphDefaultSizeList [list 100x100 120x120 160x160 200x200 256x256 300x300 400x400 500x500 600x600 700x700 300x400 400x300] 
    }
 
    # Override some defaults based on enviroment
@@ -310,6 +319,13 @@ itcl::body fvPreferences::_read { } {
       ::close $rcFile
    }
 
+   if ![info exists fvPref::GraphDefaultSizeList] {
+      set ::fvPref::GraphDefaultSizeList [list 100x100 120x120 160x160 200x200 256x256 300x300 400x400 500x500 600x600 700x700 300x400 400x300]
+   }
+
+   if ![info exists fvPref::FontSize] {
+      set ::fvPref::FontSize 12
+   }
    option add *Background          $fvPref::globalBgColor
    option add *Foreground          $fvPref::globalFgColor
    option add *HighlightBackground $fvPref::globalBgColor
@@ -350,6 +366,8 @@ itcl::body fvPreferences::save {} {
    puts $rcFile "IfUseDesktopManager  $fvPref::ifUseManager"
    puts $rcFile "IfAutoPlotPrimary    $fvPref::ifAutoPlotPrimary"
    puts $rcFile "GraphDisplaySize     {$fvPref::graphDispSize}"
+   puts $rcFile "GraphDefaultSizeList {$fvPref::GraphDefaultSizeList}"
+   puts $rcFile "FontSize             $fvPref::FontSize"
 
    if { [info exists ::fvPref::BrowserSetting] && [string trim $fvPref::BrowserSetting] != "None Defined" } {
       puts $rcFile "BrowserSetting       $fvPref::BrowserSetting"
@@ -401,6 +419,7 @@ itcl::body fvPreferences::save {} {
    set _previousDirectory ""
    catch { wm deiconify .browseDirectorySetup }
    catch { wm withdraw .browseDirectorySetup }
+   fvApp::_setupFont
 
 # puts "Options saved in $_FVRC"
 }
@@ -587,7 +606,7 @@ itcl::body fvPreferences::_buildPage_Graphs { w } {
 
    # WCS info
    
-   # checkbutton $w.wcs  -text "Use WCS Info" -variable fvPref::ifWCSInfo -font g_titleFont
+   checkbutton $w.wcs  -text "Use WCS Info" -variable fvPref::ifWCSInfo -font g_titleFont
 
    # Image Viewer
 
@@ -638,16 +657,20 @@ itcl::body fvPreferences::_buildPage_Graphs { w } {
    
    ::iwidgets::optionmenu $w.graphsize -labeltext "Graph Size:" -labelpos w \
          -command [itcl::code $this _setGraphSize $w.graphsize] -labelfont g_titleFont -font g_titleFont
-   $w.graphsize insert 0 \
-         100x100 120x120 160x160 200x200 256x256 300x300 400x400 500x500 600x600 700x700 300x400 400x300 \
-         "-----" Other...
+
+   set _graphDefaultWndw $w.graphsize
+   foreach dim $fvPref::GraphDefaultSizeList {
+       $w.graphsize insert end $dim
+   }
+   $w.graphsize insert end "-----"
+   $w.graphsize insert end "Configure.."
    $w.graphsize disable "-----"
    _setGraphSize $w.graphsize $fvPref::graphDispSize
 
    grid $w.auto       -row 1  -column 1  -sticky w  -pady $_padYAmnt \
          -padx $_padXAmnt
-   #grid $w.wcs        -row 2  -column 1  -sticky w  -pady $_padYAmnt \
-   #      -padx $_padXAmnt
+   grid $w.wcs        -row 2  -column 1  -sticky w  -pady $_padYAmnt \
+         -padx $_padXAmnt
    grid $w.viewer     -row 3  -column 1  -sticky we -pady $_padYAmnt
    grid $w.graphsize  -row 4  -column 1  -sticky w  -pady $_padYAmnt \
          -padx $_padXAmnt
@@ -731,6 +754,23 @@ itcl::body fvPreferences::_buildPage_Colors { w } {
             -padx 0
       incr row
    }
+   set currentFontSize [string trim [font configure g_titleFont -size] "-"]
+   label $w.fontSizeLabel -text "Font Size:" -font g_titleFont
+   tixControl $w.fontsize -label "" -integer true -min 1 \
+                                         -option {
+                                             font g_titleFont \
+                                         } \
+                                         -max 32 \
+                                         -value $currentFontSize \
+                                         -variable ::fvPref::FontSize
+
+  #set yearSubWidget [$topWndw.${opt}Year subwidget entry]
+  #set year [$yearSubWidget get]
+
+
+   grid $w.fontSizeLabel -row $row -column 1 -sticky w -pady 0 -padx $_padXAmnt
+   grid $w.fontsize -row $row -column 2 -sticky w  -pady 0 -padx 0
+
    grid columnconfigure $w 2 -weight 1
 }
 
@@ -743,7 +783,7 @@ itcl::body fvPreferences::_setGraphSize { menu {val ""} } {
       # Update parameter for menu selection
 
       set value [$menu get]
-      if { $value=="Other..." } {
+      if { $value=="Configure.." } {
          set val [_getGraphSize]
          _setGraphSize $menu $val
       } else {
@@ -763,43 +803,229 @@ itcl::body fvPreferences::_setGraphSize { menu {val ""} } {
    }
 }
 
+itcl::body fvPreferences::_addNewSize {} {
+    global tcl_platform
+
+    if { $tcl_platform(platform) != "windows" } {  
+       set w [.gSize childsite]
+    } else {
+       set w .gSize
+    }
+
+    set fa $w.add
+    set fd $w.delete
+    set newDim [format "%sx%s" [$fa.wide get] [$fa.hgte get]]
+
+    set idx [lsearch -exact $fvPref::GraphDefaultSizeList $newDim]
+    if { $idx >= 0 } return
+
+    # use _deleteCheckedSize to update the list
+    set ::fvPref::GraphDefaultSizeList [linsert $fvPref::GraphDefaultSizeList 0 $newDim]
+    # set ::fvPref::GraphDefaultSizeList [lsort $fvPref::GraphDefaultSizeList]
+
+    set prev_checkList $sizeCheckList
+    set sizeCheckList {}
+
+    _deleteCheckedSize add
+
+    # now to select/deselect the item user already made
+    set sizeCheckList $prev_checkList
+    for { set i 0 } { $i < [llength $fvPref::GraphDefaultSizeList] } { incr i } {
+        set dim [lindex $fvPref::GraphDefaultSizeList $i] 
+        set checkIdx [lsearch -exact $sizeCheckList $dim]
+        if { $checkIdx >= 0 } {
+           $fd.$i select
+        }
+    }
+
+    $_graphDefaultWndw select $newDim
+    set entry {}
+    lappend entry [$fa.wide get]
+    lappend entry [$fa.hgte get]
+    set ::fvPref::graphDispSize $entry
+    destroy $fd.deleteB
+
+    button $fd.deleteB -text "Delete" -command [itcl::code $this _deleteCheckedSize] -font [list Helvetica 8]
+    grid $fd.deleteB -row [expr [llength $fvPref::GraphDefaultSizeList] + 1] -column 2 -sticky e 
+}
+
+itcl::body fvPreferences::_toggleCheckedSizeState { dim } {
+    set idx [lsearch $sizeCheckList $dim]
+    if { $idx < 0 } {
+       lappend sizeCheckList $dim
+    } else {
+       set sizeCheckList [lreplace $sizeCheckList $idx $idx]
+    }
+}
+
+itcl::body fvPreferences::_deleteCheckedSize { {op "delete"} } {
+    global tcl_platform
+
+    set selectGraphSize $fvPref::graphDispSize
+    if { $tcl_platform(platform) != "windows" } {  
+       set w [.gSize childsite]
+    } else {
+       set w .gSize
+    }
+    set fd $w.delete
+    set fa $w.add
+    for { set i 0 } { $i < [llength $fvPref::GraphDefaultSizeList] } { incr i } {
+        catch { grid forget $fd.$i }
+        catch { destroy $fd.$i }
+    }
+
+    $_graphDefaultWndw delete 0 end
+
+    set newList {}
+
+    foreach dim $fvPref::GraphDefaultSizeList {
+       set idx [lsearch -exact $sizeCheckList $dim]
+
+       if { $idx < 0 } {
+          lappend newList $dim
+       }
+    }
+
+    set ::fvPref::GraphDefaultSizeList $newList
+    set sizeCheckList {}
+
+    for { set i 0 } { $i < [llength $fvPref::GraphDefaultSizeList] } { incr i } {
+        set dim [lindex $fvPref::GraphDefaultSizeList $i] 
+        checkbutton $fd.$i -font g_titleFont -text $dim \
+                           -command [itcl::code $this _toggleCheckedSizeState $dim]
+        set checkIdx [lsearch -exact $sizeCheckList $dim]
+        $fd.$i deselect
+        grid $fd.$i -row [expr $i + 1] -column 0 -sticky w 
+    }
+
+    for {set i [expr [llength $fvPref::GraphDefaultSizeList] - 1] } { $i >= 0 } {incr i -1 } {
+        $_graphDefaultWndw insert 0 [lindex $fvPref::GraphDefaultSizeList $i]
+    }
+
+    $_graphDefaultWndw insert end "-----"
+    $_graphDefaultWndw insert end "Configure.."
+    $_graphDefaultWndw disable "-----"
+
+    set ::fvPref::graphDispSize $selectGraphSize
+
+    if { $op == "delete" } {
+       # check to see if default size has been deleted
+       set dim [format "%sx%s" [lindex $fvPref::graphDispSize 0] [lindex $fvPref::graphDispSize 1]]
+       if { [llength $fvPref::GraphDefaultSizeList] <= 0 } {
+          lappend ::fvPref::GraphDefaultSizeList "300x300"
+          $fa.wide delete 0 end
+          $fa.hgte delete 0 end
+          $fa.wide insert 0 300
+          $fa.hgte insert 0 300
+          set entry {}
+          lappend entry 300
+          lappend entry 300
+          set ::fvPref::graphDispSize $entry
+          $_graphDefaultWndw insert 0 "300x300"
+       } else {
+          set idx [lsearch -exact $fvPref::GraphDefaultSizeList $dim]
+          if { $idx < 0 } {
+             # default size has been deleted
+             # pick first one
+             set token [split [lindex $fvPref::GraphDefaultSizeList 0] "x"]
+             set width [lindex $token 0]
+             set height [lindex $token 1]
+             $fa.wide delete 0 end
+             $fa.hgte delete 0 end
+             $fa.wide insert 0 $width 
+             $fa.hgte insert 0 $height
+             set entry {}
+             lappend entry $width
+             lappend entry $height
+             set ::fvPref::graphDispSize $entry
+             $_graphDefaultWndw select [lindex $fvPref::GraphDefaultSizeList 0]
+          }
+       }
+    }
+
+  
+}
 
 itcl::body fvPreferences::_getGraphSize { } {
+   global tcl_platform
    global g_titleFont
 
-   ::iwidgets::dialogshell .gSize -title "fv: Graph Size" -modality "application" 
+   if { $tcl_platform(platform) != "windows" } {  
+      ::iwidgets::dialogshell .gSize -title "fv: Graph Size" -modality "application" 
+      .gSize add OK     -text Save -command {fvPref save ; .gSize deactivate 1} -font g_titleFont
+      .gSize add CANCEL -text Cancel -command {.gSize deactivate 0} -font g_titleFont
+      .gSize default OK
+      set w [.gSize childsite]
+   } else {
+      toplevel .gSize -class Dialog
+      wm  title .gSize "fv: Preferences"
+      frame .gSize.buts
+      button .gSize.buts.save -text Save -command { fvPref save ; destroy .gSize } -font g_titleFont
+      button .gSize.buts.cancel -text Cancel -command { destroy .gSize } -font g_titleFont
+      set w .gSize
+   }
 
-   .gSize add OK     -text Ok      -command {.gSize deactivate 1} -font g_titleFont
-   .gSize add CANCEL -text Cancel  -command {.gSize deactivate 0} -font g_titleFont
-   .gSize default OK
+   label $w.titleA -text "Available Graph Size" -font g_titleFont
+   grid $w.titleA  -row 0 -column 0 -sticky w
 
-   set w [.gSize childsite]
+   # add Delete option
+   set fd [frame $w.delete -relief groove -width 500 -bd 3]
+   for { set i 0 } { $i < [llength $fvPref::GraphDefaultSizeList] } { incr i } {
+       set dim [lindex $fvPref::GraphDefaultSizeList $i] 
+       checkbutton $fd.$i -font g_titleFont -text $dim \
+                          -command [itcl::code $this _toggleCheckedSizeState $dim]
+       $fd.$i deselect
+       grid $fd.$i -row [expr $i + 1] -column 0 -sticky w 
+   }
 
-   label $w.wid -text "Width:" -font g_titleFont
-   label $w.hgt -text "Height:" -font g_titleFont
-   entry $w.wide -font g_titleFont
-   entry $w.hgte -font g_titleFont
 
-   $w.wide insert 0 [lindex $fvPref::graphDispSize 0]
-   $w.hgte insert 0 [lindex $fvPref::graphDispSize 1]
+   button $fd.deleteB -text "Delete" -command [itcl::code $this _deleteCheckedSize] -font [list Helvetica 8]
+   grid $fd.deleteB -row [expr $i + 1] -column 2 -sticky e 
+   grid $fd  -row 1 -column 0 -rowspan [llength $fvPref::GraphDefaultSizeList] -sticky w -columnspan 3
 
-   grid $w.wid   -row 1  -column 1  -padx 3 -pady 3 -sticky e
-   grid $w.hgt   -row 2  -column 1  -padx 3 -pady 3 -sticky e
-   grid $w.wide  -row 1  -column 2  -padx 3 -pady 3 -sticky w
-   grid $w.hgte  -row 2  -column 2  -padx 3 -pady 3 -sticky w
+   label $w.titleN -text "New Graph Size" -font g_titleFont
+   grid $w.titleN -row [expr [llength $fvPref::GraphDefaultSizeList] + 1]  -column 0  -padx 3 -pady 3 -sticky w -columnspan 2
 
-   set result [.gSize activate]
-   set width  [$w.wide get]
-   set height [$w.hgte get]
-   destroy .gSize
+   # add ADD option
+   set fa [frame $w.add -relief groove -bd 3]
+   label $fa.wid -text "Width:" -font g_titleFont
+   label $fa.hgt -text "Height:" -font g_titleFont
+   entry $fa.wide -font g_titleFont
+   entry $fa.hgte -font g_titleFont
+   button $fa.addB -text "Add" -command [itcl::code $this _addNewSize] -font [list Helvetica 8]
 
-   if { $result!="" && $result } {
-      if { $width > 19 && $height > 19 && $width < 2001 && $height < 2001 } {
-         return [list $width $height]
+   $fa.wide insert 0 [lindex $fvPref::graphDispSize 0]
+   $fa.hgte insert 0 [lindex $fvPref::graphDispSize 1]
+
+   grid $fa.wid   -row 1  -column 0  -padx 3 -pady 3 -sticky e
+   grid $fa.hgt   -row 2  -column 0  -padx 3 -pady 3 -sticky e
+   grid $fa.wide  -row 1  -column 1  -padx 3 -pady 3 -sticky w
+   grid $fa.hgte  -row 2  -column 1  -padx 3 -pady 3 -sticky w
+   grid $fa.addB  -row 3  -column 1  -padx 3 -pady 3 -sticky e
+   grid $fa  -row [expr [llength $fvPref::GraphDefaultSizeList] + 4] -column 0 -rowspan 4 -sticky news -columnspan 2
+
+   if { $tcl_platform(platform) != "windows" } {  
+      set result [.gSize activate]
+      set width  [$fa.wide get]
+      set height [$fa.hgte get]
+      destroy .gSize
+   } else {
+      grid .gSize.buts.save -in .gSize.buts -row 0 -column 0 -sticky e
+      grid .gSize.buts.cancel -in .gSize.buts -row 0 -column 0 -sticky e
+      grid .gSize.buts -row [expr [llength $fvPref::GraphDefaultSizeList] + 8] -column 0 -rowspan 4 -sticky news -columnspan 2
+      set width  [$fa.wide get]
+      set height [$fa.hgte get]
+   }
+
+   if { $tcl_platform(platform) != "windows" } {  
+      if { $result!="" && $result } {
+         if { $width > 19 && $height > 19 && $width < 2001 && $height < 2001 } {
+            return [list $width $height]
+         }
+         tk_messageBox -type ok -icon error -parent .fvpref -title "Bad Size" \
+               -message "The graph size entered does not fall into the range\
+               20-2000.  Reverting to previous value."
       }
-      tk_messageBox -type ok -icon error -parent .fvpref -title "Bad Size" \
-            -message "The graph size entered does not fall into the range\
-            20-2000.  Reverting to previous value."
    }
    return $fvPref::graphDispSize
 }
