@@ -95,11 +95,8 @@ extern int c_given_RADecMJD_return_Roll(ClientData clientData,
 
 int Pow_Init(Tcl_Interp *interp_instance) {
   Tcl_DString pow_env;
-  char *charptr;
+  const char *charptr;
   char temp[1000];
-#if !(defined(__WIN32__) || defined(macintosh))
-  Tcl_DString pow_script;
-#endif
 
   Tcl_DStringInit(&pow_env);
 
@@ -226,8 +223,6 @@ int Pow_Init(Tcl_Interp *interp_instance) {
 int Pow_InitExec(Tcl_Interp *interp_instance) {
   Tcl_DString pow_env;
 #if !(defined(__WIN32__) || defined(macintosh))
-  Tcl_DString pow_script;
-  char *charptr;
   char temp[1000];
 #endif
 
@@ -513,12 +508,6 @@ int Pow_CreateCommands(Tcl_Interp *interp) {
 void PowInit(char *powSetupColormapArgs, char *powInitArgs, int *status) {
   /*call this one from a standalone C or FORTRAN main (as opposed to a 
    tkAppInit file) */
-  static char *name  = "pow";
-  static char *class = "Pow";
-  static char *display = NULL;
-#if !(defined(__WIN32__) || defined(macintosh))
-  char temp[1000];
-#endif
 
   if (*status != 0) return;
 
@@ -531,12 +520,12 @@ void PowInit(char *powSetupColormapArgs, char *powInitArgs, int *status) {
   
     if (Tcl_Init(interp) == TCL_ERROR) {
       *status =  TCL_ERROR;
-      fprintf(stderr, "%s\n", interp->result);
+      fprintf(stderr, "%s\n", Tcl_GetStringResult(interp));
       return;
     }
     if (Tk_Init(interp) == TCL_ERROR) {
       *status =  TCL_ERROR;
-      fprintf(stderr, "%s\n", interp->result);
+      fprintf(stderr, "%s\n", Tcl_GetStringResult(interp));
       return;
     }
 
@@ -557,18 +546,13 @@ void PowInit(char *powSetupColormapArgs, char *powInitArgs, int *status) {
     if(Tcl_VarEval(interp, "powSetupColormap ", powSetupColormapArgs,
 		   (char *) NULL) == TCL_ERROR) {
       *status = TCL_ERROR;
-      fprintf(stderr, "Error initializing POW.\n%s\n", interp->result);
+      fprintf(stderr, "Error initializing POW.\n%s\n", Tcl_GetStringResult(interp));
     }
   }
   
   if(Tcl_VarEval(interp, "powInit ", powInitArgs, (char *) NULL) == TCL_ERROR) {
     *status = TCL_ERROR;
-    fprintf(stderr, "Error initializing POW.\n%s\n", interp->result);
+    fprintf(stderr, "Error initializing POW.\n%s\n", Tcl_GetStringResult(interp));
   }
 
 }
-
-
-
-
-
