@@ -17,7 +17,7 @@
 
 static int Pt_in_Poly( double x, double y, int nPts, double *Pts );
 
-int PowFindCurvesMinMax(char *curves, char *axis, double *min, double *max,
+int PowFindCurvesMinMax(const char *curves, char *axis, double *min, double *max,
 			int filter)
   /* Sets min and max to the minimum and maximum values found in the 
      "axis" vector of each member of the list of curves.  Initial values 
@@ -29,7 +29,7 @@ int PowFindCurvesMinMax(char *curves, char *axis, double *min, double *max,
   PowVector *current_vector;
   PowData *current_data;
   int curve_index,curveArgc;
-  char **curveArgv;
+  const char **curveArgv;
   double datum;
   int i;
 
@@ -80,14 +80,11 @@ int PowFindCurvesBBox(char *graph,
    PowCurve *current_curve;
    PowVector *Xvec, *Yvec;
    int curve_index,curveArgc;
-   char **curveArgv;
+   const char **curveArgv;
    double xdatum, ydatum, xmin, xmax, ymin, ymax, tmp;
    double lxmin, lxmax, lymin, lymax;
    int i,j, logX, logY;
-   char *optVal;
-#if !(defined(__WIN32__) || defined(macintosh))
-   PowData *current_data;
-#endif
+   const char *optVal;
 
    if(curves == NULL || strstr(curves,"NULL") != NULL ) return TCL_OK;
 
@@ -201,7 +198,7 @@ int PowFindImagesBBox(char *images, double *xleft, double *xright,
 {
   PowImage *current_image;
   int image_index,imageArgc;
-  char **imageArgv;
+  const char **imageArgv;
   double xorigin,xotherend,yorigin,yotherend,xcorner,ycorner;
 
   if(images == NULL || strstr(images,"NULL") != NULL) return TCL_OK;
@@ -349,7 +346,7 @@ int PowSortGraphMinMax( PowGraph *graph, double *xleft, double *xright,
   double tmp;
   int len;
   char *idxStr;
-  char *graphType;
+  const char *graphType;
   int zoomed;
   int xCount, yCount;
 
@@ -398,7 +395,7 @@ int PowSortGraphMinMax( PowGraph *graph, double *xleft, double *xright,
 }
 
 PowCurve *
-PowFindCurve(char *curve_name) {
+PowFindCurve(const char *curve_name) {
   Tcl_HashEntry *entry_ptr;
   PowCurve *curve_ptr;
 
@@ -415,7 +412,7 @@ PowFindCurve(char *curve_name) {
 }
 
 PowImage *
-PowFindImage(char *image_name) {
+PowFindImage(const char *image_name) {
   Tcl_HashEntry *entry_ptr;
   PowImage *image_ptr;
 
@@ -438,7 +435,6 @@ __int64 PowExtractDatumLong(PowData *data, int element) {
 }
 #else
 long long PowExtractDatumLong(PowData *data, int element) {
-  long long datum;
   return *((long long *) data->data_array + element); 
 }
 #endif
@@ -547,10 +543,10 @@ PowFindGraph(char *graph_name) {
 }
 
 
-char *PowGetObjectOption(char *graph, char *obj, char *option, char *objType)
+const char *PowGetObjectOption(char *graph, const char *obj, char *option, char *objType)
 {
    char *idxStr, gn[255];
-   char *res;
+   const char *res;
    int len;
 
    len = strlen(graph);
@@ -603,11 +599,10 @@ int PowPosToPix( double xpos, double  ypos, WCSdata *WCS,
    char powFitsHeader[14]="powFitsHeader";
    char powFitsHeaderCnt[17]="powFitsHeaderCnt";
    int i, relax, HDRcnt, ctrl, nreject=0, nwcs=0;
-   struct wcsprm *wcs;
-   char *HDRstring;
+   const char *HDRstring;
 
    /* input */
-   int ncoord, nelem;
+   int nelem;
    double pixcrd[NCOORD][4];
 
    /* output */
@@ -618,7 +613,7 @@ int PowPosToPix( double xpos, double  ypos, WCSdata *WCS,
    int coordSel;
 
    int useWCSInfo;
-   char *str = NULL;
+   const char *str = NULL;
 
    if ( WCS->graphName[0] != '\0' && strcmp(WCS->graphName, "NULL") != 0 ) {
       str = Tcl_GetVar2(interp,"useWCSInfo",WCS->graphName,TCL_GLOBAL_ONLY);
@@ -664,13 +659,17 @@ int PowPosToPix( double xpos, double  ypos, WCSdata *WCS,
             sprintf (errormsg, "Couldn't construct WCS information: %s", WCSpih_Message[status]);
             Tcl_SetResult(interp, errormsg ,TCL_VOLATILE);
             Tcl_SetVar(interp,"powWCSTranslation", WCSpih_Message[status] ,TCL_GLOBAL_ONLY);
-            return;
+            return TCL_ERROR;
          }
 
          listObj = Tcl_NewObj();
          for (i=0; i<nwcs; i++) {
            wcsname[i] = Tcl_NewStringObj(WCS->wcs[i].alt,-1);
          }
+
+         /* This is just a debug statement */
+         /* powDebugDataPrint(HDRstring, HDRcnt, WCS, nwcs, WCS->graphName); */
+
          Tcl_ListObjAppendElement( interp, listObj, Tcl_NewIntObj( nwcs ) );
          Tcl_ListObjAppendElement( interp, listObj, Tcl_NewListObj(nwcs,wcsname) );
          if ( WCS->graphName[0] != '\0' && strcmp(WCS->graphName, "NULL") != 0 ) {
@@ -690,6 +689,10 @@ int PowPosToPix( double xpos, double  ypos, WCSdata *WCS,
       WCS->wcs[coordSel].crpix[0] = WCS->refPix[0];
       WCS->wcs[coordSel].crpix[1] = WCS->refPix[1];
 
+/*
+fprintf(stdout, "---PosToPix graphName: <%s>,  coordSel: <%d>\n", WCS->graphName, coordSel);
+fflush(stdout);
+*/
       nelem = 2;
       world[0][0] = xpos;
       world[0][1] = ypos;
@@ -732,11 +735,10 @@ int PowPixToPos ( double  xpix, double  ypix, WCSdata *WCS, double *xpos, double
    char powFitsHeader[14]="powFitsHeader";
    char powFitsHeaderCnt[17]="powFitsHeaderCnt";
    int i, relax, HDRcnt, ctrl, nreject=0, nwcs=0;
-   struct wcsprm *wcs;
-   char *HDRstring;
+   const char *HDRstring;
 
    /* input */
-   int ncoord, nelem;
+   int nelem;
    double pixcrd[NCOORD][4];
 
    /* output */
@@ -747,7 +749,7 @@ int PowPixToPos ( double  xpix, double  ypix, WCSdata *WCS, double *xpos, double
    int coordSel;
 
    int useWCSInfo;
-   char *str = NULL;
+   const char *str = NULL;
 
    if ( WCS->graphName[0] != '\0' && strcmp(WCS->graphName, "NULL") != 0 ) {
       str = Tcl_GetVar2(interp,"useWCSInfo",WCS->graphName,TCL_GLOBAL_ONLY);
@@ -791,13 +793,17 @@ int PowPixToPos ( double  xpix, double  ypix, WCSdata *WCS, double *xpos, double
             sprintf (errormsg, "Couldn't construct WCS information: %s", WCSpih_Message[status]);
             Tcl_SetResult(interp, errormsg ,TCL_VOLATILE);
             Tcl_SetVar(interp,"powWCSTranslation", WCSpih_Message[status] ,TCL_GLOBAL_ONLY);
-            return;
+            return TCL_ERROR;
          }
 
          listObj = Tcl_NewObj();
          for (i=0; i<nwcs; i++) {
              wcsname[i] = Tcl_NewStringObj(WCS->wcs[i].alt,-1);
          }
+
+         /* This is just a debug statement */
+         /* powDebugDataPrint(HDRstring, HDRcnt, WCS, nwcs, WCS->graphName); */
+
          Tcl_ListObjAppendElement( interp, listObj, Tcl_NewIntObj( nwcs ) );
          Tcl_ListObjAppendElement( interp, listObj, Tcl_NewListObj(nwcs,wcsname) );
 
@@ -814,6 +820,13 @@ int PowPixToPos ( double  xpix, double  ypix, WCSdata *WCS, double *xpos, double
       } else if ( WCS->curveName[0] != '\0' && strcmp(WCS->curveName, "NULL") != 0 ) {
          coordSel = atoi(Tcl_GetVar2(interp,"powWCSName",WCS->curveName,TCL_GLOBAL_ONLY));
       }
+
+/*
+fprintf(stdout, "PixToPos graphName: <%s> coordSel: <%d>\n", WCS->graphName, coordSel);
+fprintf(stdout, "         WCS->refPix[0]: <%20.15f> WCS->refPix[1]: <%20.15f>\n", WCS->refPix[0], WCS->refPix[1]);
+fflush(stdout);
+*/
+
       WCS->wcs[coordSel].crpix[0] = WCS->refPix[0];
       WCS->wcs[coordSel].crpix[1] = WCS->refPix[1];
 
@@ -837,6 +850,7 @@ int PowPixToPos ( double  xpix, double  ypix, WCSdata *WCS, double *xpos, double
 
       *xpos = world[0][0];
       *ypos = world[0][1];
+
       Tcl_SetVar(interp,"powWCSTranslation", "0" ,TCL_GLOBAL_ONLY);
    } else {
       xpix -= WCS->refPix[0];
@@ -862,9 +876,7 @@ int PowIsInRegion( double* pos , double *parReg,
     char tmp_shape[10];
     char *ptr;
     double x,y,k,b,x1,y1;
-    double *angles;
-    int i,n;
-    double sum;
+    int i;
     double *polygon_vertex;
     int result;
 
@@ -1003,9 +1015,6 @@ int PowCalRegion( PowImage* image_ptr, char *regionFile, int *rect,
       SAORegion *Rgn;
 
       int xmin,ymin,xmax,ymax, signflag;
-#if !(defined(__WIN32__) || defined(macintosh))
-      double x,y;
-#endif
 
       regionInputFile = 0;
       if (strcmp(regionFile,"NONE") != 0) {
@@ -1233,3 +1242,39 @@ static int Pt_in_Poly( double x,
    }
    return( flag );
 }
+
+void powDebugDataPrint (char *header,
+                        int headerCnt,
+                        WCSdata *WCS,
+                        int nwcs,
+                        char *graphName)
+{
+   int k = 0;
+   int i;
+   char currentStr[81];
+   char *ptr;
+   
+   ptr = header;
+
+   fprintf(stdout, "graphName: <%s>, headerCnt: <%d>\n", graphName, headerCnt);
+   fflush(stdout); 
+   for (i= 0; i< strlen(header); i+=80 ) {
+       memset(currentStr, '\0', 81);
+       strncpy(currentStr, ptr, 80);
+       fprintf(stdout, "<%s>\n", currentStr);
+       fflush(stdout); 
+       k++; 
+       ptr += 80;
+   }
+
+   fprintf(stdout, "final count: <%d>\n\nnumber of wcs: <%d>\nwcsname: ", k, nwcs );
+   fprintf(stdout, "wcsname: ");
+   fflush(stdout); 
+
+   for (i= 0; i< nwcs; i++ ) {
+       fprintf(stdout, "<%s>", WCS->wcs[i].alt);
+   }
+
+   fprintf(stdout, "\n");
+   fflush(stdout); 
+}
