@@ -38,8 +38,7 @@ int FillinWCSStructure ( WCSdata *WCS )
    char powFitsHeader[14]="powFitsHeader";
    char powFitsHeaderCnt[17]="powFitsHeaderCnt";
    int i, relax, HDRcnt, ctrl, nreject=0, nwcs=0;
-   struct wcsprm *wcs;
-   char *HDRstring;
+   const char *HDRstring;
    int status;
    int coordSel;
    Tcl_Obj *listObj;
@@ -110,8 +109,7 @@ int PowParseWCS( Tcl_Interp *interp, WCSdata *WCS,
    Tcl_Obj **listElems;
    int row, col, nElem, nDims, dim;
    char *type;
-   char *ptr;
-   int itype,swap=0;
+   int swap=0;
 
    PowInitWCS( WCS, MAX_WCS_DIMS );
 
@@ -247,7 +245,7 @@ void PowDumpWCSstructure ( WCSdata *WCS ) {
    fprintf(stdout, "WCS->cdFrwd[1]  : <%20.15f,%20.15f>\n", WCS->cdFrwd[1][0], WCS->cdFrwd[1][1]);
    fprintf(stdout, "WCS->cdRvrs[0]  : <%20.15f,%20.15f>\n", WCS->cdRvrs[0][0], WCS->cdRvrs[0][1]);
    fprintf(stdout, "WCS->cdRvrs[1]  : <%20.15f,%20.15f>\n", WCS->cdRvrs[1][0], WCS->cdRvrs[1][1]);
-   fprintf(stdout, "WCS->rot        : <%d>\n", WCS->rot);
+   fprintf(stdout, "WCS->rot        : <%20.15f>\n", WCS->rot);
    fprintf(stdout, "WCS->haveWCSinfo: <%d>\n", WCS->haveWCSinfo);
    fprintf(stdout, "**********************************\n");
    fflush(stdout);
@@ -386,7 +384,7 @@ int PowWCSInitCurve(ClientData clientData, Tcl_Interp *interp,
    FillinWCSStructure(&curve_ptr->WCS);
 
    if ( curve_ptr->WCS.type[0] == '\0' ) {
-      char *WCSstring;
+      const char *WCSstring;
 
       WCSstring = Tcl_GetVar2(interp, "powWCS", curveName,TCL_GLOBAL_ONLY);
       /* Tcl_SetVar2(interp,"powWCS", curveName, "", TCL_GLOBAL_ONLY); */
@@ -400,7 +398,7 @@ int PowWCSInitGraph( PowGraph *graph, char *curves, char *images,
    PowCurve *current_curve;
    PowImage *current_image;
    int index,Argc;
-   char **Argv;
+   const char **Argv;
    char *p;
 
    graph->WCS.type[0] = '\0';
@@ -655,9 +653,6 @@ int pow_worldpos(double xpix, double ypix,
    double cond2r= pi/180.0;
    double deps = 1.0e-5;
    int itype;
-#if !(defined(__WIN32__) || defined(macintosh))
-   double decout, raout;
-#endif
 
    /*  Apply Transform Matrix  */
 
