@@ -524,8 +524,8 @@ itcl::body RegionList::regionProperty { } {
    set rgnIdx [$regionParam(rgns) selected]
    set rgn [$regionParam(rgns) rgnAtIndex $rgnIdx]
 
-puts "[$rgn getSign]"
-puts "$regionParam(currSign)$regionParam(currShape)$regionParam(currDescr)"
+#puts "[$rgn getSign]"
+#puts "$regionParam(currSign)$regionParam(currShape)$regionParam(currDescr)"
 }
 
 ########################################################################
